ewa.ruleparser

Package ewa :: Module ruleparser |
[hide private]
[frames] | no frames]

# Module ruleparser

source code

A parser for the rule configuration format.

see doc/rule_grammar.rst for documentation.

Classes | [hide private]
| ParseError
| RuleParser

Functions | [hide private]
_to_datetime(dt) | source code
parse_string(s, debug=False) | source code
parse_file(fp, debug=False) | source code
lex_file(fp, debug=False) | source code
lex_string(s, debug=False) | source code

Variables | [hide private]
| PARSEDEBUG = `False`
| __package__ = ``'``ewa``'``